summaryrefslogtreecommitdiffstats
path: root/k9author/k9avidecode.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'k9author/k9avidecode.cpp')
-rw-r--r--k9author/k9avidecode.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/k9author/k9avidecode.cpp b/k9author/k9avidecode.cpp
index b89acc1..22019b4 100644
--- a/k9author/k9avidecode.cpp
+++ b/k9author/k9avidecode.cpp
@@ -19,7 +19,7 @@
#include <libavformat/avformat.h>
#endif
-#include <qimage.h>
+#include <tqimage.h>
#include <dlfcn.h>
#include <klocale.h>
#include <cstdlib>
@@ -41,18 +41,18 @@ void av_free_packet(AVPacket *pkt)
#endif
#endif
-k9AviDecode::k9AviDecode(QObject *parent, const char *name)
- : QObject(parent, name) {
+k9AviDecode::k9AviDecode(TQObject *tqparent, const char *name)
+ : TQObject(tqparent, name) {
if (glibref==0) {
CodecHandle=dlopen("libavcodec.so",RTLD_LAZY | RTLD_GLOBAL);
FormatHandle=dlopen("libavformat.so",RTLD_LAZY | RTLD_GLOBAL);
}
if (!CodecHandle) {
- m_error =i18n("Cannot open then library %1").arg("libavcodec");
+ m_error =i18n("Cannot open then library %1").tqarg("libavcodec");
return;
}
if (!FormatHandle) {
- m_error =i18n("Cannot open then library %1").arg("libavformat");
+ m_error =i18n("Cannot open then library %1").tqarg("libavformat");
return;
}
m_error="";
@@ -98,14 +98,14 @@ k9AviDecode::~k9AviDecode() {
#include "k9avidecode.moc"
-bool k9AviDecode::open(const QString & _fileName) {
+bool k9AviDecode::open(const TQString & _fileName) {
m_error="";
if (m_opened)
close();
// Open video file
if (av_open_input_file(&m_FormatCtx, _fileName.utf8(), NULL, 0, NULL)!=0) {
- m_error=i18n("Couldn't open the file %1").arg(_fileName);
+ m_error=i18n("Couldn't open the file %1").tqarg(_fileName);
return false; // Couldn't open file}
}
// Retrieve stream information
@@ -211,7 +211,7 @@ void k9AviDecode::readFrame(double _seconds) {
(AVPicture*)m_Frame, m_CodecCtx->pix_fmt,
m_CodecCtx->width, m_CodecCtx->height);
// convert frame to QImage
SaveFrame(m_FrameRGB, m_CodecCtx->width,
m_CodecCtx->height);
}
@@ -225,7 +225,7 @@ void k9AviDecode::readFrame(double _seconds) {
}
void k9AviDecode::SaveFrame(AVFrame *pFrame, int width, int height) {
- QImage pix;
+ TQImage pix;
int len =(int) (3*width*height);
char c[255];
// Write header
@@ -268,11 +268,11 @@ bool k9AviDecode::opened() const {
}
-QString k9AviDecode::getFileName() const {
+TQString k9AviDecode::getFileName() const {
return m_fileName;
}
-QString k9AviDecode::getError() const {
+TQString k9AviDecode::getError() const {
return m_error;
}
@@ -211,7 +211,7 @@ void k9AviDecode::readFrame(double _seconds) {
(AVPicture*)m_Frame, m_CodecCtx->pix_fmt,
m_CodecCtx->width, m_CodecCtx->height);
- // convert frame to QImage
+ // convert frame to TQImage
SaveFrame(m_FrameRGB, m_CodecCtx->width,
m_CodecCtx->height);